# Class: virtualbox_windows
#
# This module manages virtualbox in windows
#
# Parameters: version = virtualbox verison
#             build   = virtualbox build
#
# Actions:
#
# Requires: puppetlabs-powershell
#
# Sample Usage: Just write class{'virtualbox_windows':}
#
class virtualbox_windows ($version = $::virtualbox_windows::params::version, $build = $::virtualbox_windows::params::build) inherits virtualbox_windows::params {
  $url = "http://download.virtualbox.org/virtualbox/${version}/VirtualBox-${version}-${build}-Win.exe"
  $destination = "C:\\Windows\\Temp\\VirtualBox-${version}-${build}-Win.exe"


  case $::operatingsystem{
    "windows" : {
    	  exec { "Download Oracle VM VirtualBox ${version}":
       		command  =>  template('virtualbox_windows/download.ps1'),
    		  logoutput => true,
          onlyif => template('virtualbox_windows/checkfileexists.ps1'),
          provider => powershell,
        } ->

        package { "Oracle VM VirtualBox ${version}" :
          ensure          => installed,
          source          => $destination,
          install_options => ["/silent"],
        }
    }

    default : {
          fail("This operative system [${operatingsystem}] is not (yet) supported")
    }
    }

}
